@@ -68,7 +68,7 @@ FAILEDOPERATION_COSBUCKETNOTEXIST = 'FailedOperation.CosBucketNotExist'
 # 无权限访问 Cos bucket。
 FAILEDOPERATION_COSBUCKETNOTPERMISSION = 'FailedOperation.CosBucketNotPermission'
 
-# Cos 角色不存在。
+# Cos 角色不存在，请前往 控制台 -> 功能配置 -> 直播截图&鉴黄 页面进行授权。
 FAILEDOPERATION_COSROLENOTEXISTS = 'FailedOperation.CosRoleNotExists'
 
 # 2天内有产生流量，域名处于锁定期间，2天内无流量产生才允许删除域名。
@@ -326,6 +326,12 @@ INVALIDPARAMETER_CLOUDCRTIDERROR = 'InvalidParameter.CloudCrtIdError'
 # 赠送的腾讯云域名已过期。
 INVALIDPARAMETER_CLOUDDOMAINISSTOP = 'InvalidParameter.CloudDomainIsStop'
 
+# 模版使用中。
+INVALIDPARAMETER_CONFINUSED = 'InvalidParameter.ConfInUsed'
+
+# 配置没有找到。
+INVALIDPARAMETER_CONFNOTFOUND = 'InvalidParameter.ConfNotFound'
+
 # 证书使用中。
 INVALIDPARAMETER_CRTDATEINUSING = 'InvalidParameter.CrtDateInUsing'
 
@@ -422,6 +428,12 @@ INVALIDPARAMETER_MPPLUGINNOUSE = 'InvalidParameter.MpPluginNoUse'
 # 其他错误。
 INVALIDPARAMETER_OTHERERROR = 'InvalidParameter.OtherError'
 
+# 转码模板已存在。
+INVALIDPARAMETER_PROCESSORALREADYEXIST = 'InvalidParameter.ProcessorAlreadyExist'
+
+# 规则没有找到。
+INVALIDPARAMETER_RULENOTFOUND = 'InvalidParameter.RuleNotFound'
+
 # 同一会话输出流发生变化。
 INVALIDPARAMETER_SESSIONOUTPUTSTREAMCHANGED = 'InvalidParameter.SessionOutputStreamChanged'
 
@@ -506,9 +518,6 @@ RESOURCENOTFOUND_PUSHDOMAINNORECORD = 'ResourceNotFound.PushDomainNoRecord'
 # 账号停服，请先冲正开通服务后再操作。
 RESOURCENOTFOUND_STOPSERVICE = 'ResourceNotFound.StopService'
 
-# 非活跃流。
-RESOURCENOTFOUND_STREAMNOTALIVE = 'ResourceNotFound.StreamNotAlive'
-
 # TaskId 不存在。
 RESOURCENOTFOUND_TASKID = 'ResourceNotFound.TaskId'
 
